@@ -8,6 +8,7 @@ extern crate lazy_static;
 pub(crate) mod checker;
 pub mod cli;
 mod dictionary;
+mod ignore;
 pub(crate) mod interactor;
 pub mod kak;
 pub(crate) mod os_io;
@@ -19,6 +20,7 @@ pub(crate) mod tokens;
 use checker::{Checker, InteractiveChecker, NonInteractiveChecker};
 use dictionary::Dictionary;
 pub use dictionary::EnchantDictionary;
+use ignore::Ignore;
 use interactor::{ConsoleInteractor, Interactor};
 pub use os_io::StandardIO;
 use project::{Project, ProjectId, ProjectPath, RelativePath};
