@@ -4,6 +4,7 @@ use std::collections::{HashMap, HashSet};
 
 use crate::repository::Operation;
 use crate::repository::ProjectInfo;
+use crate::Ignore;
 use crate::Repository;
 use crate::{ProjectId, ProjectPath, RelativePath};
 
@@ -25,6 +26,52 @@ impl FakeRepository {
     }
 }
 
+impl Ignore for FakeRepository {
+    fn is_ignored(&self, word: &str) -> Result<bool> {
+        Ok(self.global.contains(word))
+    }
+
+    fn is_skipped_file_name(&self, file_name: &str) -> Result<bool> {
+        Ok(self.skip_file_names.contains(file_name))
+    }
+
+    fn is_ignored_for_extension(&self, word: &str, extension: &str) -> Result<bool> {
+        if let Some(words) = self.by_extension.get(extension) {
+            Ok(words.contains(&word.to_string()))
+        } else {
+            Ok(false)
+        }
+    }
+
+    fn is_ignored_for_project(&self, word: &str, project_id: ProjectId) -> Result<bool> {
+        if let Some(words) = self.by_project.get(&project_id) {
+            Ok(words.contains(&word.to_string()))
+        } else {
+            Ok(false)
+        }
+    }
+
+    fn is_ignored_for_path(
+        &self,
+        word: &str,
+        project_id: ProjectId,
+        path: &RelativePath,
+    ) -> Result<bool> {
+        if let Some(words) = self
+            .by_project_and_path
+            .get(&(project_id, path.to_string()))
+        {
+            Ok(words.contains(&word.to_string()))
+        } else {
+            Ok(false)
+        }
+    }
+
+    fn is_skipped_path(&self, project_id: ProjectId, path: &RelativePath) -> Result<bool> {
+        Ok(self.skipped_paths.contains(&(project_id, path.to_string())))
+    }
+}
+
 impl Repository for FakeRepository {
     fn project_exists(&self, project_path: &ProjectPath) -> Result<bool> {
         Ok(self.get_project_id(project_path).is_ok())
@@ -74,19 +121,11 @@ impl Repository for FakeRepository {
         Ok(())
     }
 
-    fn is_ignored(&self, word: &str) -> Result<bool> {
-        Ok(self.global.contains(word))
-    }
-
     fn skip_file_name(&mut self, file_name: &str) -> Result<()> {
         self.skip_file_names.insert(file_name.to_string());
         Ok(())
     }
 
-    fn is_skipped_file_name(&self, file_name: &str) -> Result<bool> {
-        Ok(self.skip_file_names.contains(file_name))
-    }
-
     fn ignore_for_extension(&mut self, word: &str, extension: &str) -> Result<()> {
         let entry = &mut self
             .by_extension
@@ -96,28 +135,12 @@ impl Repository for FakeRepository {
         Ok(())
     }
 
-    fn is_ignored_for_extension(&self, word: &str, extension: &str) -> Result<bool> {
-        if let Some(words) = self.by_extension.get(extension) {
-            Ok(words.contains(&word.to_string()))
-        } else {
-            Ok(false)
-        }
-    }
-
     fn ignore_for_project(&mut self, word: &str, project_id: ProjectId) -> Result<()> {
         let entry = &mut self.by_project.entry(project_id).or_insert_with(Vec::new);
         entry.push(word.to_string());
         Ok(())
     }
 
-    fn is_ignored_for_project(&self, word: &str, project_id: ProjectId) -> Result<bool> {
-        if let Some(words) = self.by_project.get(&project_id) {
-            Ok(words.contains(&word.to_string()))
-        } else {
-            Ok(false)
-        }
-    }
-
     fn ignore_for_path(
         &mut self,
         word: &str,
@@ -132,31 +155,11 @@ impl Repository for FakeRepository {
         Ok(())
     }
 
-    fn is_ignored_for_path(
-        &self,
-        word: &str,
-        project_id: ProjectId,
-        path: &RelativePath,
-    ) -> Result<bool> {
-        if let Some(words) = self
-            .by_project_and_path
-            .get(&(project_id, path.to_string()))
-        {
-            Ok(words.contains(&word.to_string()))
-        } else {
-            Ok(false)
-        }
-    }
-
     fn skip_path(&mut self, project_id: ProjectId, path: &RelativePath) -> Result<()> {
         self.skipped_paths.insert((project_id, path.to_string()));
         Ok(())
     }
 
-    fn is_skipped_path(&self, project_id: ProjectId, path: &RelativePath) -> Result<bool> {
-        Ok(self.skipped_paths.contains(&(project_id, path.to_string())))
-    }
-
     fn remove_ignored(&mut self, word: &str) -> Result<()> {
         let was_present = self.global.remove(word);
         ensure!(was_present, "word was not globally ignored");
